@@ -1,10 +1,10 @@
-'''Main package API entry point.
+"""Main package API entry point.
 
 Import core objects here.
-'''
+"""
 
 from .model import ModelBase, make_declarative_base
-from .query import Query
+from .query import Query, QueryModel
 from .manager import Manager, ManagerMixin
 from .session import Session
 
@@ -18,4 +18,12 @@ from .__meta__ import (
     __license__
 )
 
-__all__ = ['ModelBase', 'make_declarative_base', 'Query', 'Manager', 'ManagerMixin', 'Session']
+__all__ = [
+    'ModelBase',
+    'make_declarative_base',
+    'Query',
+    'QueryModel',
+    'Manager',
+    'ManagerMixin',
+    'Session'
+]
