@@ -18,19 +18,15 @@ class ModelMeta(DeclarativeMeta):
         - Declarative ORM events
     """
     def __new__(mcs, name, bases, dct):
+        # Determine if primary key is defined for dct or any of its bases.
+        base_dcts = [dct] + [base.__dict__ for base in bases]
+
         if (not dct.get('__tablename__')
                 and dct.get('__table__') is None
-                and has_primary_key(dct)):
+                and any([has_primary_key(base) for base in base_dcts])):
             # Set to underscore version of class name.
             dct['__tablename__'] = camelcase_to_underscore(name)
 
-        # add bind key to table info via __table_args__
-        if not dct.get('__table_args__'):
-            dct['__table_args__'] = {}
-
-        dct['__table_args__'].setdefault('info', {})
-        dct['__table_args__']['info']['bind_key'] = dct.get('__bind_key__')
-
         # Set __events__ to expected default so that it's updatable when
         # initializing. E.g. if class definition sets __events__=None but
         # defines decorated events, then we want the final __events__ attribute
@@ -42,7 +38,13 @@ class ModelMeta(DeclarativeMeta):
         return DeclarativeMeta.__new__(mcs, name, bases, dct)
 
     def __init__(cls, name, bases, dct):
-        super(ModelMeta, cls).__init__(name, bases, dct)
+        bind_key = dct.pop('__bind_key__', None)
+
+        DeclarativeMeta.__init__(cls, name, bases, dct)
+
+        if bind_key is not None:
+            cls.__table__.info['bind_key'] = bind_key
+
         events.register(cls, dct)
 
 
